@@ -3,7 +3,6 @@ const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
-const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
@@ -193,11 +192,7 @@ const ChatView = new Lang.Class({
         let selectedColor = context.get_background_color(Gtk.StateFlags.SELECTED);
         context.restore();
 
-        let [found, linkColor] = context.lookup_color("link_color");
-        if (!found) {
-            linkColor = new Gdk.RGBA();
-            linkColor.parse('blue');
-        }
+        let linkColor = context.get_color(Gtk.StateFlags.LINK);
 
         let buffer = this._view.get_buffer();
         let tagTable = buffer.get_tag_table();
@@ -420,7 +415,7 @@ const ChatView = new Lang.Class({
         item = new Gtk.MenuItem({ label: _("Copy Link Address") });
         item.connect('activate',
             function() {
-                let clipboard = Polari.util_get_clipboard_for_widget(item);
+                let clipboard = Gtk.Clipboard.get_default(item.get_display());
                 clipboard.set_text(url, -1);
             });
         menu.append(item);
